https://github.com/python/cpython/commit/d755701b2aa35d7ec05f16fea410191f034e85c1
commit: d755701b2aa35d7ec05f16fea410191f034e85c1
branch: 3.14
author: Miss Islington (bot) <[email protected]>
committer: vsajip <[email protected]>
date: 2026-08-12T21:11:28+01:00
summary:

[3.14] Update logging.config.listen() docstrings to mention dictConfig() 
(GH-155479) (GH-155529)

(cherry picked from commit 791b5731d0c999d671e5a74a4c6557ddfa2a72a7)

files:
M Lib/logging/config.py

diff --git a/Lib/logging/config.py b/Lib/logging/config.py
index e0524eb5e3d89c2..be53150d12d54ab 100644
--- a/Lib/logging/config.py
+++ b/Lib/logging/config.py
@@ -952,8 +952,9 @@ def listen(port=DEFAULT_LOGGING_CONFIG_PORT, verify=None):
     Start up a socket server on the specified port, and listen for new
     configurations.
 
-    These will be sent as a file suitable for processing by fileConfig().
-    Returns a Thread object on which you can call start() to start the server,
+    These will be sent as a file suitable for processing by dictConfig() or
+    fileConfig(). Returns a Thread object on which you can call start() to
+    start the server,
     and which you can join() when appropriate. To stop the server, call
     stopListening().
 
@@ -971,8 +972,8 @@ class ConfigStreamHandler(StreamRequestHandler):
         """
         Handler for a logging configuration request.
 
-        It expects a completely new logging configuration and uses fileConfig
-        to install it.
+        It expects a completely new logging configuration and uses dictConfig
+        or fileConfig to install it.
         """
         def handle(self):
             """
@@ -980,7 +981,7 @@ def handle(self):
 
             Each request is expected to be a 4-byte length, packed using
             struct.pack(">L", n), followed by the config file.
-            Uses fileConfig() to do the grunt work.
+            Uses dictConfig() or fileConfig() to do the grunt work.
             """
             try:
                 conn = self.connection

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to